@@ -1,7 +1,8 @@
 {{ module.name }}: {
     {% for function in module.functions %}
-            {{ function.name }}: function(callback_function, argv){
-                Dajaxice.call('{{function.get_callable_path}}', callback_function, argv);
+            {% if function.doc and DAJAXICE_JS_DOCSTRINGS %}/* {{ function.doc|default:'' }}*/ {% endif %}
+            {{ function.name }}: function(callback_function, argv, custom_settings){
+                Dajaxice.call('{{function.get_callable_path}}', callback_function, argv, custom_settings);
             }{% if not forloop.last %},{% endif %}
     {% endfor %}
             
