@@ -44,16 +44,19 @@ def dajaxice_request(request, call):
     Return the apropiate json according app_name and method.
     """
     return DajaxiceRequest(request, call).process()
-    
+
+
 @cache_control(max_age=DajaxiceRequest.get_cache_control())
 def js_core(request):
     """
-    Return the dajax JS code according settings.DAJAXICE_FUNCTIONS registered functions.
+    Return the dajax JS code according settings.DAJAXICE_FUNCTIONS
+    registered functions.
     """
-    data = {'dajaxice_js_functions':DajaxiceRequest.get_js_functions(),
+    data = {'dajaxice_js_functions': DajaxiceRequest.get_js_functions(),
             'DAJAXICE_URL_PREFIX': DajaxiceRequest.get_media_prefix(),
-            'DAJAXICE_XMLHTTPREQUEST_JS_IMPORT':DajaxiceRequest.get_xmlhttprequest_js_import(),
-            'DAJAXICE_JSON2_JS_IMPORT':DajaxiceRequest.get_json2_js_import(),
-            'DAJAXICE_EXCEPTION':DajaxiceRequest.get_exception_message()
-             }
-    return render_to_response('dajaxice/dajaxice.core.js', data, mimetype="text/javascript" )
\ No newline at end of file
+            'DAJAXICE_XMLHTTPREQUEST_JS_IMPORT': DajaxiceRequest.get_xmlhttprequest_js_import(),
+            'DAJAXICE_JSON2_JS_IMPORT': DajaxiceRequest.get_json2_js_import(),
+            'DAJAXICE_EXCEPTION': DajaxiceRequest.get_exception_message(),
+            'DAJAXICE_JS_DOCSTRINGS': DajaxiceRequest.get_js_docstrings()}
+
+    return render_to_response('dajaxice/dajaxice.core.js', data, mimetype="text/javascript")
